SyncError class

Details of a single sync failure

Constructors

SyncError({required String operationId, required String collection, required String message, Object? error})
const

Properties

collection String
The collection it belonged to
final
error Object?
The full error object
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message
final
operationId String
The operation that failed
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited